﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;

namespace howto_resize_bitmap_extensions
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Let the user browse for the directory.
        private void btnPickDirectory_Click(object sender, EventArgs e)
        {
            try
            {
                fbdDirectory.SelectedPath = txtDirectory.Text;
            }
            catch
            {
            }

            if (fbdDirectory.ShowDialog() == DialogResult.OK)
            {
                txtDirectory.Text = fbdDirectory.SelectedPath;
            }
        }

        // Process the files in the selected directory.
        private void btnGo_Click(object sender, EventArgs e)
        {
            // See which values we will set.
            bool set_width = chkSetWidth.Checked;
            bool set_height = chkSetHeight.Checked;

            if (!set_width && !set_height)
            {
                MessageBox.Show("You must set at least one of the width and height.",
                    "No Boxes Checked", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Get the new width and height values.
            int new_width = 0;
            int new_height = 0;
            int.TryParse(txtNewWidth.Text, out new_width);
            int.TryParse(txtNewHeight.Text, out new_height);

            if (set_width && (new_width < 1))
            {
                MessageBox.Show("The new width must be at least 1.",
                    "Invalid Width", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            if (set_height && (new_height < 1))
            {
                MessageBox.Show("The new height must be at least 1.",
                    "Invalid Height", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            this.Cursor = Cursors.WaitCursor;
            this.Refresh();

            DirectoryInfo dir_info = new DirectoryInfo(txtDirectory.Text);
            foreach (FileInfo file_info in dir_info.GetFiles())
            {
                try
                {
                    string ext = file_info.Extension.ToLower();
                    if ((ext == ".bmp") || (ext == ".gif") ||
                        (ext == ".jpg") || (ext == ".jpeg") ||
                        (ext == ".png"))
                    {
                        using (Bitmap bm = new Bitmap(file_info.FullName))
                        {
                            picWorking.Image = bm;
                            picWorking.Refresh();
                            
                            Bitmap bm2 = bm.Resize(
                                set_width, set_height, new_width, new_height);

                            string new_name = file_info.FullName;
                            new_name = new_name.Substring(0,
                                new_name.Length - ext.Length);
                            new_name += "_s" + ext;
                            bm2.SaveImage(new_name);
                        }
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error processing file '" +
                        file_info.Name + "'\n" + ex.Message,
                        "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
                }
            } // foreach file_info

            picWorking.Image = null;
            this.Text = "howto_resize_pics2";
            this.Cursor = Cursors.Default;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            txtDirectory.Text = Application.StartupPath;
        }
    }
}
